# Commands

## Core Commands (v0.3.0)

- [oasr](ROOT.md) - Global flags and options
- [oasr registry](REGISTRY.md) - Manage skill registry (validate, add, remove, list, sync)
- [oasr diff](DIFF.md) - Show status of tracked skills (NEW in v0.3.0)
- [oasr sync](SYNC.md) - Refresh outdated tracked skills (CHANGED in v0.3.0)
- [oasr use](USE.md) - Copy skill(s) to target directory (with tracking)
- [oasr find](FIND.md) - Find/discover skills in your file system
- [oasr validate](VALIDATE.md) - Validate a skill
- [oasr clean](CLEAN.md) - Clean up the registry
- [oasr adapter](ADAPTER.md) - Generate IDE/Tooling adapters
- [oasr update](UPDATE.md) - Update the `oasr` CLI
- [oasr info](INFO.md) - Show detailed information about a skill
- [oasr help](HELP.md) - Show the help menu

## Deprecated Commands (v0.2.0)

These commands have been reorganized in v0.3.0:

- [oasr add](ADD.md) - **Moved to** `oasr registry add`
- [oasr list](LIST.md) - **Moved to** `oasr registry list`
- [oasr rm](RM.md) - **Moved to** `oasr registry rm`
- [oasr status](STATUS.md) - **Replaced by** `oasr registry -v` and `oasr diff`
